@@ -172,7 +172,8 @@ readGDAL = function(fname, offset, region.dim, output.dim, ..., half.cell=c(0.5,
 		if (!odim_flag) cellsize = abs(c(gt[2],gt[6]))
 		else {
 			icellsize = abs(c(gt[2],gt[6]))
-			span <- icellsize * rev(d)
+			span <- icellsize * rev(d[1:2])
+# bug report Mike Sumner 070215
 			cellsize <- span / rev(output.dim)
 		}
 		ysign <- sign(gt[6])
